[![Build Status](https://travis-ci.com/schmidtfederico/apscheduler-ui.svg?branch=master)](https://travis-ci.com/schmidtfederico/apscheduler-ui)

[![Coverage Status](https://coveralls.io/repos/github/schmidtfederico/apscheduler-ui/badge.svg?branch=master)](https://coveralls.io/github/schmidtfederico/apscheduler-ui?branch=master)